/* Reset */
*, *::before, *::after {
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
}

/* Reset */
.jp-Notebook {
    padding: unset;
    /* outline: none; */
    /* overflow: auto; */
    background: unset;
}

/* Reset */
.jp-RenderedHTMLCommon {
    padding: 0;
}

/* Anchor links */
.anchor-link {
    display: none;
}
h1:hover .anchor-link, h2:hover .anchor-link, h3:hover .anchor-link {
    display: inline-block;
}

/* Markdown cells: Remove prompt */
.jp-Cell-inputWrapper .jp-InputPrompt {
    display: none;
}

/* Code cells: Show prompt */
.jp-CodeCell .jp-Cell-inputWrapper .jp-InputPrompt {
    display: block;
}

/* Prompt fixes */
.jp-InputPrompt, .jp-OutputPrompt{
    overflow: visible;
}

/* Lab uses move for the input prompts */
.jp-Notebook .jp-Cell .jp-InputPrompt {
    cursor: default;
}

/* Editor max-width */
.jp-InputArea-editor {
    width: 1px;
}

/* Editor colors */
.jp-Editor .highlight {
    margin: 0.4em;
    background: var(--jp-cell-editor-background);
    color: var(--jp-mirror-editor-variable-color);
}

/* Editor colors */
.jp-Editor .highlight pre {
    background: none;
    border: none;
    margin: 0;
    overflow-x: auto;
}

/* Material mkdocs */
.jp-RenderedHTMLCommon p {
    font-size: .8rem;
    line-height: 1.6;
}

.jp-RenderedHTMLCommon li {
    font-size: .8rem;
    line-height: 1.6;
}

.jp-RenderedHTMLCommon h1 {
    margin: 0 0 1.25em;
    color: var(--md-default-fg-color--light);
    font-weight: 300;
    font-size: 2em;
    line-height: 1.3;
    letter-spacing: -0.01em;
}

.jp-RenderedHTMLCommon h2 {
    margin: 1.6em 0 .64em;
    font-weight: 300;
    font-size: 1.965em;
    line-height: 1.4;
    letter-spacing: -0.01em;
}

.jp-RenderedHTMLCommon h3 {
    margin: 1.6em 0 .8em;
    font-weight: 400;
    font-size: 1.57em;
    line-height: 1.5;
    letter-spacing: -0.01em;
}

.jp-RenderedHTMLCommon hr {
    border: none;
}


/* Tags on cells */
/* Mostly copying this from straight Jupyter */
.celltoolbar {
    border: none;
    background: #EEE;
    border-radius: 2px 2px 0px 0px;
    width: 100%;
    height: 29px;
    padding-right: 4px;
    box-orient: horizontal;
    box-align: stretch;
    display: flex;
    flex-direction: row;
    align-items: stretch;
    box-pack: end;
    justify-content: flex-start;
    display: -webkit-flex;
}

.celltoolbar .tags_button_container {
    display: flex;
}

.celltoolbar .tags_button_container .tag-container {
    display: flex;
    flex-direction: row;
    flex-grow: 1;
    overflow: hidden;
    position: relative;
}

.celltoolbar .tags_button_container .tag-container .cell-tag {
    background-color: #fff;
    white-space: nowrap;
    margin: 3px 4px;
    padding: 0 4px;
    border-radius: 1px;
    border: 1px solid #ccc;
    box-shadow: none;
    width: inherit;
    font-size: 11px;
    font-family: "Roboto Mono",SFMono-Regular,Consolas,Menlo,monospace;
    height: 22px;
    /* line-height: 22px; */
    display: inline-block;
}

/* Bokeh plots table no hover */
.bk-plot-wrapper tbody tr {
    background: none !important;
}
.bk-plot-wrapper tbody tr:hover {
    background: none !important;
}
